#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.osm_interfaces.product_scene import ProductScene
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ProductScenes(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ProductScenes
                | 
                | A collection of ProductScenes contained in a given
                | ProductDocument.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ProductScene)
        self.product_scenes = com_object

    def add_product_scene_full(self, i_name: str, i_reference_products: tuple) -> ProductScene:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddProductSceneFull(CATBSTR iName,
                | CATSafeArrayVariant iReferenceProducts) As ProductScene
                | 
                |     Creates a new FULL scene from a set of products and adds it to the
                |     ProductScenes collection.
                | 
                |     Parameters:
                | 
                |         iName
                |             The name of the new scene 
                |         iReferenceProducts
                |             Products used as root nodes of the new scene 
                | 
                |     Returns:
                |         The created new full scene 
                |     Example:
                | 
                |              This example creates the SpareWheel new scene from the reference
                |              product
                |             FrontRightWheel and adds the scene to the ToolKits
                |             collection.
                |
                |             Dim SpareWheel As ProductScene
                |             Set SpareWheel = ToolKits.AddProductSceneFull("SpareWheel", FrontRightWheel)

        :param str i_name:
        :param tuple i_reference_products:
        :rtype: ProductScene
        """
        return ProductScene(self.product_scenes.AddProductSceneFull(i_name, i_reference_products))

    def add_product_scene_partial(self, i_name: str, i_reference_products: tuple) -> ProductScene:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddProductScenePartial(CATBSTR iName,
                | CATSafeArrayVariant iReferenceProducts) As ProductScene
                | 
                |     Creates a new DELTA scene from a set of products and adds it to the
                |     ProductScenes collection.
                | 
                |     Parameters:
                | 
                |         iName
                |             The name of the new scene 
                |         iReferenceProducts
                |             Products used as root nodes of the new scene 
                | 
                |     Returns:
                |         The created new delta scene 
                |     Example:
                | 
                |              This example creates the SpareWheel new scene from the reference
                |              product
                |             FrontRightWheel and adds the scene to the ToolKits
                |             collection.
                |
                |             Dim SpareWheel As ProductScene
                |             Set SpareWheel = ToolKits.AddProductScenePartial("SpareWheel", FrontRightWheel)

        :param str i_name:
        :param tuple i_reference_products:
        :rtype: ProductScene
        """
        return ProductScene(self.product_scenes.AddProductScenePartial(i_name, i_reference_products))

    def item(self, i_index: cat_variant) -> ProductScene:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ProductScene
                | 
                |     Returns a scene using its index or its name from the ProductScenes
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the ProductScene to retrieve from the
                |             collection of ProductScenes. As a numerics, this index is the rank of the
                |             ProductScene in the collection. The index of the first ProductScene in the
                |             collection is 1, and the index of the last ProductScene is Count. As a string,
                |             it is the name you assigned to the ProductScene. 
                | 
                |     Returns:
                |         The retrieved ProductScene. 
                |     Example:
                | 
                |              This example retrieves in ThisProductScene the ninth
                |              ProductScene,
                |             and in ThatProductScene the ProductScene named
                |             ProductScene3 from the TheProductScenes collection.
                |
                |             Dim ThisProductScene As ProductScene
                |             Set ThisProductScene = TheProductScenes.Item(9)
                |             Dim ThatProductScene As ProductScene
                |             Set ThatProductScene = TheProductScenes.Item("ProductScene3")

        :param cat_variant i_index:
        :rtype: ProductScene
        """
        return ProductScene(self.product_scenes.Item(i_index))

    def remove(self, i_product_scene: ProductScene) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(ProductScene iProductScene)
                | 
                |     Removes a product-scene from the ProductScenes collection.
                | 
                |     Parameters:
                | 
                |         iScene
                |             The scene to remove. 
                | 
                |     Example:
                | 
                |              This example removes the Engine product-scene from the ToolKits
                |              collection.
                |
                |             ToolKits.Remove Engine

        :param ProductScene i_product_scene:
        :rtype: None
        """
        return self.product_scenes.Remove(i_product_scene.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(product_scenes)
        # #     Dim iProductScene (2)
        # #     product_scenes.Remove iProductScene
        # #     remove = iProductScene
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ProductScenes(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_grr_route import SchGRRRoute
from pycatia.system_interfaces.any_object import AnyObject


class SchArrowDisplay(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchArrowDisplay
                | 
                | Manage the graphical representation of a schematic route.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_arrow_display = com_object

    def is_arrow_shown(self, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub IsArrowShown(boolean oBYes)
                | 
                |     Query whether flow arrows are shown (arrow attributes
                |     exist).
                | 
                |     Parameters:
                | 
                |         oBYes
                |             If TRUE, then Flow arrows are shown (arrow attributes exist). If
                |             FALSE, then Flow arrows are not shown (arrow attributes do not exist).
                |
                |     Example:
                |
                |          Dim objThisIntf As SchArrowDisplay
                |          Dim bVar1 As boolean
                |           ...
                |          objThisIntf.IsArrowShownbVar1

        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_arrow_display.IsArrowShown(o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'is_arrow_shown'
        # # vba_code = """
        # # Public Function is_arrow_shown(sch_arrow_display)
        # #     Dim oBYes (2)
        # #     sch_arrow_display.IsArrowShown oBYes
        # #     is_arrow_shown = oBYes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_arrow(self, i_grr: SchGRRRoute, i_seg_num: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetArrow(SchGRRRoute iGRR,
                | long iSegNum)
                | 
                |     Add arrow display attributes on the route.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             iGRR means apply only to segments of iGRR.
                |             (if iGRR = NULL, apply to segments of all GRR's of the route, and ignore iSegNum)
                |         iSegNum
                |             iSegNum = 0 means apply to all segments of iGRR.
                |             iSegnum > 0 means apply to only to segment number iSegNum iGRR.
                | 
                |     Example:
                | 
                |          Dim objThisIntf As SchArrowDisplay
                |          Dim objArg1 As SchGRRRoute
                |          Dim intVar2 As Integer
                |           ...
                |          objThisIntf.SetArrowobjArg1,intVar2

        :param SchGRRRoute i_grr:
        :param int i_seg_num:
        :rtype: None
        """
        return self.sch_arrow_display.SetArrow(i_grr.com_object, i_seg_num)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_arrow'
        # # vba_code = """
        # # Public Function set_arrow(sch_arrow_display)
        # #     Dim iGRR (2)
        # #     sch_arrow_display.SetArrow iGRR
        # #     set_arrow = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def unset_arrow(self, i_grr: SchGRRRoute, i_seg_num: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub UnsetArrow(SchGRRRoute iGRR,
                | long iSegNum)
                | 
                |     Remove arrow display attributes on the route.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             iGRR means apply only to segments of iGRR. (if iGRR = NULL, apply to segments of all GRR's of the route, and ignore iSegNum) 
                |         iSegNum
                |             iSegNum = 0 means apply to all segments of iGRR. iSegnum > 0 means apply to only to segment number iSegNum iGRR. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchArrowDisplay
                |          Dim objArg1 As SchGRRRoute
                |          Dim intVar2 As Integer
                |           ...
                |          objThisIntf.UnsetArrowobjArg1,intVar2

        :param SchGRRRoute i_grr:
        :param int i_seg_num:
        :rtype: None
        """
        return self.sch_arrow_display.UnsetArrow(i_grr.com_object, i_seg_num)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'unset_arrow'
        # # vba_code = """
        # # Public Function unset_arrow(sch_arrow_display)
        # #     Dim iGRR (2)
        # #     sch_arrow_display.UnsetArrow iGRR
        # #     unset_arrow = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchArrowDisplay(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.behavior_interfaces.behavior import Behavior


class BehaviorExtension(Behavior):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATBehaviorInterfaces.Behavior
                |                         BehaviorExtension
                | 
                | Manages the behaviors of a technological object.
                | Role: This interface allows to select and perform the behaviors (tasks)
                | associated to a technological object. A behavior extension is obtained from an
                | object using the method GetItem of CATIABase with in argument the keyword
                | "CATGetBehaviorExtension".
                | 
                | Example:
                | 
                |      Set RootPart = CATIA.ActiveDocument.Part
                |      Set MyExtension = RootPart.GetItem("CATGetBehaviorExtensions")
                |      Set listBehavior = MyExtension.Behaviors
                |      MyExtension.SelectBehavior("MyBehavior")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.behavior_extension = com_object

    @property
    def extension_class(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ExtensionClass() As CATBSTR (Read Only)
                | 
                |     Returns the type of the technological object associated to this behavior
                |     extension.

        :rtype: str
        """

        return self.behavior_extension.ExtensionClass

    def select_behavior(self, behavior_name: str) -> Behavior:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func SelectBehavior(CATBSTR BehaviorName) As Behavior
                | 
                |     Selects and executes a behavior of the technological object. The wanted
                |     behavior is specified by its name.
                | 
                |     Parameters:
                | 
                |         BehaviorName
                |             the name of the behavior.

        :param str behavior_name:
        :rtype: Behavior
        """
        return Behavior(self.behavior_extension.SelectBehavior(behavior_name))

    def __repr__(self):
        return f'BehaviorExtension(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.geometric_elements import GeometricElements
from pycatia.sketcher_interfaces.circle_2D import Circle2D
from pycatia.sketcher_interfaces.control_point_2D import ControlPoint2D
from pycatia.sketcher_interfaces.ellipse_2D import Ellipse2D
from pycatia.sketcher_interfaces.geometry_2D import Geometry2D
from pycatia.sketcher_interfaces.hyperbola_2D import Hyperbola2D
from pycatia.sketcher_interfaces.line_2D import Line2D
from pycatia.sketcher_interfaces.parabola_2D import Parabola2D
from pycatia.sketcher_interfaces.point_2D import Point2D
from pycatia.sketcher_interfaces.spline_2D import Spline2D
from pycatia.system_interfaces.any_object import AnyObject


class Factory2D(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Factory2D
                | 
                | Interface to the factory for 2D objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.factory_2d = com_object

    def create_circle(self, i_center_x: float, i_center_y: float, i_radius: float, i_start_param: float,
                      i_end_param: float) -> Circle2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func CreateCircle(double iCenterX,
                | double iCenterY,
                | double iRadius,
                | double iStartParam,
                | double iEndParam) As Circle2D
                | 
                |     Creates and returns a 2D circle arc.
                | 
                |     Parameters:
                | 
                |         iCenterX
                |             The X coordinate of the circle center 
                |         iCenterY
                |             The Y coordinate of the circle center 
                |         iRadius
                |             The radius of the circle 
                |         iStartParam
                |             The beginning parameter of the circle.
                |             This parameter is an angle value between 0 included and 2PI
                |             excluded. Parameter values are computed from the axis horizontal direction in
                |             the trigonometrical direction. 
                |         iEndParam
                |             The end parameter of the circle.
                |             This parameter may take any value between iStartParam excluded and
                |             4PI included.

        :param float i_center_x:
        :param float i_center_y:
        :param float i_radius:
        :param float i_start_param:
        :param float i_end_param:
        :rtype: Circle2D
        """
        return Circle2D(self.factory_2d.CreateCircle(i_center_x, i_center_y, i_radius, i_start_param, i_end_param))

    def create_closed_circle(self, i_center_x: float, i_center_y: float, i_radius: float) -> Circle2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func CreateClosedCircle(double iCenterX,
                | double iCenterY,
                | double iRadius) As Circle2D
                | 
                |     Creates and returns a closed 2D circle.
                | 
                |     Parameters:
                | 
                |         iCenterX
                |             The X coordinate of the circle center 
                |         iCenterY
                |             The Y coordinate of the circle center 
                |         iRadius
                |             The radius of the circle

        :param float i_center_x:
        :param float i_center_y:
        :param float i_radius:
        :rtype: Circle2D
        """
        return Circle2D(self.factory_2d.CreateClosedCircle(i_center_x, i_center_y, i_radius))

    def create_closed_ellipse(self, i_center_x: float, i_center_y: float, i_major_x: float, i_major_y: float,
                              i_major_radius: float, i_minor_radius: float) -> Ellipse2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func CreateClosedEllipse(double iCenterX,
                | double iCenterY,
                | double iMajorX,
                | double iMajorY,
                | double iMajorRadius,
                | double iMinorRadius) As Ellipse2D
                | 
                |     Creates and returns a closed 2D ellipse.
                | 
                |     Parameters:
                | 
                |         iCenterX
                |             The X coordinate of the ellipse center 
                |         iCenterY
                |             The Y coordinate of the ellipse center 
                |         iMajorX
                |             The X component of the major axis direction 
                |         iMajorY
                |             The Y component of the Major axis direction 
                |         iMajorRadius
                |             The length of the major axis 
                |         iMinorRadius
                |             The length of the minor axis

        :param float i_center_x:
        :param float i_center_y:
        :param float i_major_x:
        :param float i_major_y:
        :param float i_major_radius:
        :param float i_minor_radius:
        :rtype: Ellipse2D
        """
        return Ellipse2D(
            self.factory_2d.CreateClosedEllipse(i_center_x, i_center_y, i_major_x, i_major_y, i_major_radius,
                                                i_minor_radius))

    def create_control_point(self, i_x: float, i_y: float) -> ControlPoint2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func CreateControlPoint(double iX,
                | double iY) As ControlPoint2D
                | 
                |     Creates and returns a 2D spline control point.
                | 
                |     Parameters:
                | 
                |         iX
                |             The X coordinate of point to create 
                |         iY
                |             The Y coordinate of point to create

        :param float i_x:
        :param float i_y:
        :rtype: ControlPoint2D
        """
        return ControlPoint2D(self.factory_2d.CreateControlPoint(i_x, i_y))

    def create_ellipse(self, i_center_x: float, i_center_y: float, i_major_x: float, i_major_y: float,
                       i_major_radius: float, i_minor_radius: float, i_start_param: float,
                       i_end_param: float) -> Ellipse2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func CreateEllipse(double iCenterX,
                | double iCenterY,
                | double iMajorX,
                | double iMajorY,
                | double iMajorRadius,
                | double iMinorRadius,
                | double iStartParam,
                | double iEndParam) As Ellipse2D
                | 
                |     Creates and returns a 2D ellipse arc.
                | 
                |     Parameters:
                | 
                |         iCenterX
                |             The X coordinate of the ellipse center 
                |         iCenterY
                |             The Y coordinate of the ellipse center 
                |         iMajorX
                |             The X component of the major axis direction 
                |         iMajorY
                |             The Y component of the major axis direction 
                |         iMajorRadius
                |             The length of the major axis 
                |         iMinorRadius
                |             The length of the minor axis 
                |         iStartParam
                |             The beginning parameter of the ellipse.
                |             This parameter is an angle value between 0 included and 2PI
                |             excluded. Parameter values are computed from the major axis direction in the
                |             trigonometrical direction. 
                |         iEndParam
                |             The end parameter of the ellipse.
                |             This parameter may take any value between iStartParam excluded and
                |             4PI included.

        :param float i_center_x:
        :param float i_center_y:
        :param float i_major_x:
        :param float i_major_y:
        :param float i_major_radius:
        :param float i_minor_radius:
        :param float i_start_param:
        :param float i_end_param:
        :rtype: Ellipse2D
        """
        return Ellipse2D(
            self.factory_2d.CreateEllipse(i_center_x, i_center_y, i_major_x, i_major_y, i_major_radius, i_minor_radius,
                                          i_start_param, i_end_param))

    def create_hyperbola(self, i_center_x: float, i_center_y: float, i_axis_x: float, i_axis_y: float,
                         i_major_radius: float, i_minor_radius: float) -> Hyperbola2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func CreateHyperbola(double iCenterX,
                | double iCenterY,
                | double iAxisX,
                | double iAxisY,
                | double iMajorRadius,
                | double iMinorRadius) As Hyperbola2D
                | 
                |     Creates and returns a hyperbola.
                | 
                |     Parameters:
                | 
                |         iCenterX
                |             The X coordinate of the hyperbola center 
                |         iCenterY
                |             The Y coordinate of the hyperbola center 
                |         iAxisX
                |             The X coordinate of the major axis direction 
                |         iAxisY
                |             The Y coordinate of the major axis direction 
                |         iMajorRadius
                |             The length of the major axis 
                |         iMinorRadius
                |             The length of the minor axis

        :param float i_center_x:
        :param float i_center_y:
        :param float i_axis_x:
        :param float i_axis_y:
        :param float i_major_radius:
        :param float i_minor_radius:
        :rtype: Hyperbola2D
        """
        return Hyperbola2D(
            self.factory_2d.CreateHyperbola(i_center_x, i_center_y, i_axis_x, i_axis_y, i_major_radius, i_minor_radius))

    def create_intersection(self, i_geometry: Reference) -> Geometry2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func CreateIntersection(Reference iGeometry) As Geometry2D
                | 
                |     Creates and returns the intersection of an object with the
                |     sketch.
                | 
                |     Parameters:
                | 
                |         iGeometry
                |             The object to intersect with the sketch

        :param Reference i_geometry:
        :rtype: Geometry2D
        """
        return Geometry2D(self.factory_2d.CreateIntersection(i_geometry.com_object))

    def create_intersections(self, i_geometry: Reference) -> GeometricElements:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func CreateIntersections(Reference iGeometry) As
                | GeometricElements
                | 
                |     Creates and returns the possible intersections of an object with the
                |     sketch.
                | 
                |     Parameters:
                | 
                |         iGeometry
                |             The object to intersect with the sketch

        :param Reference i_geometry:
        :rtype: GeometricElements
        """
        return GeometricElements(self.factory_2d.CreateIntersections(i_geometry.com_object))

    def create_line(self, i_x1: float, i_y1: float, i_x2: float, i_y2: float) -> Line2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func CreateLine(double iX1,
                | double iY1,
                | double iX2,
                | double iY2) As Line2D
                | 
                |     Creates and returns a 2D line.
                | 
                |     Parameters:
                | 
                |         iX1
                |             The X coordinate of line first extremity 
                |         iY1
                |             The Y coordinate of line first extremity 
                |         iX2
                |             The X coordinate of line second extremity 
                |         iY2
                |             The Y coordinate of line second extremity

        :param float i_x1:
        :param float i_y1:
        :param float i_x2:
        :param float i_y2:
        :rtype: Line2D
        """
        return Line2D(self.factory_2d.CreateLine(i_x1, i_y1, i_x2, i_y2))

    def create_line_from_vector(self, i_x1: float, i_y1: float, i_ux: float, i_uy: float) -> Line2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func CreateLineFromVector(double iX1,
                | double iY1,
                | double iUX,
                | double iUY) As Line2D
                | 
                |     Creates and returns a 2D line.
                | 
                |     Parameters:
                | 
                |         iX1
                |             The X coordinate of the line origin 
                |         iY1
                |             The Y coordinate of the line origin 
                |         iUX
                |             The X component of the line vector 
                |         iUY
                |             The Y component of the line vector

        :param float i_x1:
        :param float i_y1:
        :param float i_ux:
        :param float i_uy:
        :rtype: Line2D
        """
        return Line2D(self.factory_2d.CreateLineFromVector(i_x1, i_y1, i_ux, i_uy))

    def create_parabola(self, i_center_x: float, i_center_y: float, i_axis_x: float, i_axis_y: float,
                        i_focal_distance: float) -> Parabola2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func CreateParabola(double iCenterX,
                | double iCenterY,
                | double iAxisX,
                | double iAxisY,
                | double iFocalDistance) As Parabola2D
                | 
                |     Creates and returns a parabola.
                | 
                |     Parameters:
                | 
                |         iCenterX
                |             The X coordinate of the parabola center 
                |         iCenterY
                |             The Y coordinate of the parabola center 
                |         iAxisX
                |             The X coordinate of the major axis direction 
                |         iAxisY
                |             The Y coordinate of the major axis direction 
                |         iFocalDistance
                |             The parabola focal distance

        :param float i_center_x:
        :param float i_center_y:
        :param float i_axis_x:
        :param float i_axis_y:
        :param float i_focal_distance:
        :rtype: Parabola2D
        """
        return Parabola2D(self.factory_2d.CreateParabola(i_center_x, i_center_y, i_axis_x, i_axis_y, i_focal_distance))

    def create_point(self, i_x: float, i_y: float) -> Point2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func CreatePoint(double iX,
                | double iY) As Point2D
                | 
                |     Creates and returns a 2D point.
                | 
                |     Parameters:
                | 
                |         iX
                |             The X coordinate of point to create 
                |         iY
                |             The Y coordinate of point to create

        :param float i_x:
        :param float i_y:
        :rtype: Point2D
        """
        return Point2D(self.factory_2d.CreatePoint(i_x, i_y))

    def create_projection(self, i_geometry: Reference) -> Geometry2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func CreateProjection(Reference iGeometry) As Geometry2D
                | 
                |     Creates and returns the projection of an object on the
                |     sketch.
                | 
                |     Parameters:
                | 
                |         iGeometry
                |             The object to project on the sketch

        :param Reference i_geometry:
        :rtype: Geometry2D
        """
        return Geometry2D(self.factory_2d.CreateProjection(i_geometry.com_object))

    def create_projections(self, i_geometry: Reference) -> GeometricElements:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func CreateProjections(Reference iGeometry) As
                | GeometricElements
                | 
                |     Creates and returns the possible projections of an object on the
                |     sketch.
                | 
                |     Parameters:
                | 
                |         iGeometry
                |             The object to project on the sketch

        :param Reference i_geometry:
        :rtype: GeometricElements
        """
        return GeometricElements(self.factory_2d.CreateProjections(i_geometry.com_object))

    def create_spline(self, i_poles: tuple) -> Spline2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func CreateSpline(CATSafeArrayVariant iPoles) As Spline2D
                | 
                |     Creates and returns a 2D b-spline.
                | 
                |     Parameters:
                | 
                |         iPoles
                |             An array of CATIAPoint2D forming the poles of the
                |             b-spline.

        :param tuple i_poles:
        :rtype: Spline2D
        """
        return Spline2D(self.factory_2d.CreateSpline(tuple(p2d.com_object for p2d in i_poles)))

    def __repr__(self):
        return f'Factory2D(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_display_groups import ABQDisplayGroups
from pycatia.abq_automation_interfaces.abq_global_element_assignment import ABQGlobalElementAssignment
from pycatia.abq_automation_interfaces.abq_jobs import ABQJobs
from pycatia.abq_automation_interfaces.abq_solution_case import ABQSolutionCase
from pycatia.abq_automation_interfaces.abq_steps import ABQSteps
from pycatia.system_interfaces.any_object import AnyObject


class ABQAnalysisCase(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAnalysisCase
                | 
                | Represents an Abaqus analysis case (ABQAnalysisCase) object.
                | 
                | Role: Access an Abaqus analysis case object or determine its properties. An
                | ABQAnalysisCase object contains the collection of Abaqus steps (ABQSteps ) and
                | Abaqus jobs ( ABQJobs ). An Abaqus analysis case object contains the data
                | required to manage and run an Abaqus finite element analysis.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_analysis_case = com_object

    @property
    def display_groups(self) -> ABQDisplayGroups:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DisplayGroups() As ABQDisplayGroups (Read Only)
                | 
                |     Returns the Abaqus display groups associated with this analysis
                |     case.
                | 
                |     Returns:
                |         The collection of display groups. 
                |     Example:
                |         The following example retrieves the Abaqus display group collection
                |         DisplayGroups in ListDisplayGroups.
                | 
                |          Dim MyCase As ABQAnalysisCase
                |          Dim ListDisplayGroups As ABQDisplayGroups
                |          Set ListDisplayGroups = MyCase.DisplayGroups

        :rtype: ABQDisplayGroups
        """

        return ABQDisplayGroups(self.abq_analysis_case.DisplayGroups)

    @property
    def global_elem_assignment(self) -> ABQGlobalElementAssignment:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GlobalElemAssignment() As ABQGlobalElementAssignment (Read
                | Only)
                | 
                |     Returns the Global Element Assignement feature associated with this
                |     analysis case.
                | 
                |     Returns:
                |         The associated Global Element Assignement feature . 
                |     Example:
                |         The following example retrieves the Global Element Assignement feature
                |         collection GlobalElemAssignment in
                |         oGlobalElementAssignment.
                | 
                |          Dim MyCase As ABQAnalysisCase
                |          Dim GlobalElementAssignment As
                |          ABQGlobalElementAssignment
                |          Set GlobalElementAssignment = MyCase.GlobalElemAssignment

        :rtype: ABQGlobalElementAssignment
        """

        return ABQGlobalElementAssignment(self.abq_analysis_case.GlobalElemAssignment)

    @property
    def jobs(self) -> ABQJobs:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Jobs() As ABQJobs (Read Only)
                | 
                |     Returns the Abaqus jobs associated with this analysis
                |     case.
                | 
                |     Returns:
                |         The collection of jobs. 
                |     Example:
                |         The following example retrieves the Abaqus job collection Jobs in
                |         ListJobs.
                | 
                |          Dim MyCase As ABQAnalysisCase
                |          Dim ListJobs As ABQJobs
                |          Set ListJobs = MyCase.Jobs

        :rtype: ABQJobs
        """

        return ABQJobs(self.abq_analysis_case.Jobs)

    @property
    def solution_case(self) -> ABQSolutionCase:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SolutionCase() As ABQSolutionCase (Read Only)
                | 
                |     Returns the Abaqus solution case associated with this analysis
                |     case.
                | 
                |     Returns:
                |         The associated Abaqus solution case. 
                |     Example:
                |         The following example retrieves the Abaqus solution case collection
                |         SolutionCase in SolutionCase.
                | 
                |          Dim MyCase As ABQAnalysisCase
                |          Dim SolutionCase As ABQSolutionCase
                |          Set SolutionCase = MyCase.SolutionCase

        :rtype: ABQSolutionCase
        """

        return ABQSolutionCase(self.abq_analysis_case.SolutionCase)

    @property
    def steps(self) -> ABQSteps:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Steps() As ABQSteps (Read Only)
                | 
                |     Returns the Abaqus analysis steps associated with this analysis
                |     case.
                | 
                |     Returns:
                |         The collection of analysis steps. 
                |     Example:
                |         The following example retrieves the Abaqus analysis step collection
                |         Steps in ListSteps.
                | 
                |          Dim MyCase As ABQAnalysisCase
                |          Dim ListSteps As ABQSteps
                |          Set ListSteps = MyCase.Steps

        :rtype: ABQSteps
        """

        return ABQSteps(self.abq_analysis_case.Steps)

    def __repr__(self):
        return f'ABQAnalysisCase(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class CD5ID(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CD5ID
                | 
                | Represents the ENOVIA V6 Integration identifier.
                | Role: It identifies an ENOVIA V6 Object thanks to its
                | Type/Name/Revision(/Version). It is managed by CD5Engine.
                | 
                | See also:
                |     CD5Engine, CD5Structure
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.cd5_id = com_object

    def get_id(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetID() As CATBSTR
                | 
                |     Returns the Identifier of the ENOVIA V6 Object associated to the
                |     CD5ID.
                | 
                |     Returns:
                |         The identifier String of the ENOIACD5ID. 
                |     Example:
                | 
                |           The following example returns in oID the identifier corresponding to
                |           the CD5ID oCD5ID.
                |
                |          Dim oCD5Engine As CD5Engine
                |          Set oCD5Engine = CATIA.GetItem("CD5Engine")
                |          Dim oCD5ID As CD5ID
                |          Set oCD5ID = oCD5Engine.GetIDFromTNR("CATProduct For Team", "MyProduct", "---")
                |          Dim oID As CATBSTR
                |          oID = oCD5ID.GetID

        :rtype: str
        """
        return self.cd5_id.GetID()

    def __repr__(self):
        return f'CD5ID(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.plane import Plane
from pycatia.in_interfaces.reference import Reference


class HybridShapePlaneNormal(Plane):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.Plane
                |                             HybridShapePlaneNormal
                | 
                | Normal plane.
                | Role: Allows to access data of the plane feature normal to a curve at a given
                | point.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_plane_normal = com_object

    @property
    def curve(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Curve() As Reference
                | 
                |     Role: Get the curve to which the plane is to be normal.
                | 
                |     Parameters:
                | 
                |         oCurve
                |             reference curve. 
                | 
                |     See also:
                |         Reference 
                |     Returns:
                |         HRESULT S_OK if Ok E_FAIL else return error code for C++
                |         Implementations 
                |     See also:
                |         HybridShapeFactory

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_plane_normal.Curve)

    @curve.setter
    def curve(self, reference_curve: Reference):
        """
        :param Reference reference_curve:
        """

        self.hybrid_shape_plane_normal.Curve = reference_curve

    @property
    def point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Point() As Reference
                | 
                |     Role: Get the point where the plane is to be normal.
                | 
                |     Parameters:
                | 
                |         oPoint
                |             point 
                | 
                |     See also:
                |         Reference 
                |     Returns:
                |         HRESULT S_OK if Ok E_FAIL else return error code for C++
                |         Implementations 
                |     See also:
                |         HybridShapeFactory

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_plane_normal.Point)

    @point.setter
    def point(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_plane_normal.Point = reference_point.com_object

    def __repr__(self):
        return f'HybridShapePlaneNormal(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class SpecV4SettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         SpecV4SettingAtt
                | 
                | Represents the V4/V5 SPEC setting controller object.
                | Role: The V4/V5 SPEC setting controller object deals with the setting
                | parameters displayed in the V4/V5SPEC property page. To access this property
                | page:
                | 
                |     Click the Options command in the Tools menu
                |     Click + left of General to unfold the workbench list
                |     Click Compatibility
                | 
                | 
                | The different options for V4/V5SPEC tab:
                | The Step By Step Update And Reroute
                | The Draft Feature Migration Mode
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.spec_v4_setting_att = com_object

    @property
    def draft_feature_migration_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DraftFeatureMigrationMode() As
                | CATV4IV4V5SpecDraftMigrationEnum
                | 
                |     Returns or sets the activation state of the mode of migration for draft
                |     feature.
                |     Role: This setting parameter manages the activation of the mode of
                |     migration for draft feature during a Copy/Paste As Spec.

        :return: enum catv4_iv4_v5_spec_draft_migration_enum
        :rtype: int
        """

        return self.spec_v4_setting_att.DraftFeatureMigrationMode

    @draft_feature_migration_mode.setter
    def draft_feature_migration_mode(self, value: int):
        """
        :param int value: enum catv4_iv4_v5_spec_draft_migration_enum
        """

        self.spec_v4_setting_att.DraftFeatureMigrationMode = value

    @property
    def step_by_step_update_and_reroute(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StepByStepUpdateAndReroute() As boolean
                | 
                |     Returns or sets the activation state of Step By Step Update And
                |     Reroute.
                |     Role: The Step By Step Update And Reroute setting parameter manages the
                |     activation of the step by step update and reroute during a Copy/Paste As Spec
                |     when solids are involved.

        :rtype: bool
        """

        return self.spec_v4_setting_att.StepByStepUpdateAndReroute

    @step_by_step_update_and_reroute.setter
    def step_by_step_update_and_reroute(self, value: bool):
        """
        :param bool value:
        """

        self.spec_v4_setting_att.StepByStepUpdateAndReroute = value

    def get_draft_feature_migration_mode_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDraftFeatureMigrationModeInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the DraftFeatureMigrationMode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.spec_v4_setting_att.GetDraftFeatureMigrationModeInfo(admin_level, o_locked)

    def get_step_by_step_update_and_reroute_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetStepByStepUpdateAndRerouteInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the StepByStepUpdateAndReroute setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.spec_v4_setting_att.GetStepByStepUpdateAndRerouteInfo(admin_level, o_locked)

    def set_draft_feature_migration_mode_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDraftFeatureMigrationModeLock(boolean iLock)
                | 
                |     Locks or unlocks the DraftFeatureMigrationMode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.spec_v4_setting_att.SetDraftFeatureMigrationModeLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_draft_feature_migration_mode_lock'
        # # vba_code = """
        # # Public Function set_draft_feature_migration_mode_lock(spec_v4_setting_att)
        # #     Dim iLock (2)
        # #     spec_v4_setting_att.SetDraftFeatureMigrationModeLock iLock
        # #     set_draft_feature_migration_mode_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_step_by_step_update_and_reroute_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetStepByStepUpdateAndRerouteLock(boolean iLock)
                | 
                |     Locks or unlocks the StepByStepUpdateAndReroute setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.spec_v4_setting_att.SetStepByStepUpdateAndRerouteLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_step_by_step_update_and_reroute_lock'
        # # vba_code = """
        # # Public Function set_step_by_step_update_and_reroute_lock(spec_v4_setting_att)
        # #     Dim iLock (2)
        # #     spec_v4_setting_att.SetStepByStepUpdateAndRerouteLock iLock
        # #     set_step_by_step_update_and_reroute_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SpecV4SettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_str_functional_interfaces.sfm_member import SFMMember
from pycatia.in_interfaces.reference import Reference


class SFMMemberPointUpToLimit(SFMMember):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATStrFunctionalInterfaces.SfmObject
                |                         CATStrFunctionalInterfaces.SfmProfile
                |                            CATStrFunctionalInterfaces.SfmMember
                |                                 SfmMemberPointUpToLimit
                | 
                | Interface to manage Member created with one point, one direction and one
                | limit.
                | Role: To manage member created with one point, one direction and one
                | limit.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sfm_member_point_up_to_limit = com_object

    @property
    def direction(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Direction() As Reference
                | 
                |     Returns or sets the direction.
                | 
                |     Example:
                |         This example retrieves in Direction the direction for the
                |         SfmMemberPointUpToLimit feature.
                | 
                |          Dim Direction As Reference
                |          Set Direction = SfmMemberPointUpToLimit.Direction

        :rtype: Reference
        """

        return Reference(self.sfm_member_point_up_to_limit.Direction)

    @direction.setter
    def direction(self, value: Reference):
        """
        :param Reference value:
        """

        self.sfm_member_point_up_to_limit.Direction = value.com_object

    @property
    def direction_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DirectionOrientation() As long
                | 
                |     Returns or sets the direction orientation.
                | 
                |     Example:
                |         This example retrieves in DirectionOrientation the direction
                |         orientation for the SfmMemberPointUpToLimit feature.
                | 
                |          Dim DirectionOrientation As Integer
                |          Set DirectionOrientation = SfmMemberPointUpToLimit.DirectionOrientation

        :rtype: int
        """

        return self.sfm_member_point_up_to_limit.DirectionOrientation

    @direction_orientation.setter
    def direction_orientation(self, value: int):
        """
        :param int value:
        """

        self.sfm_member_point_up_to_limit.DirectionOrientation = value

    @property
    def limit(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Limit() As Reference
                | 
                |     Returns or sets the limit.
                | 
                |     Example:
                |         This example retrieves in Limit the limit for the
                |         SfmMemberPointUpToLimit feature.
                | 
                |          Dim Limit As Reference
                |          Set Limit = SfmMemberPointUpToLimit.Limit

        :rtype: Reference
        """

        return Reference(self.sfm_member_point_up_to_limit.Limit)

    @limit.setter
    def limit(self, value: Reference):
        """
        :param Reference value:
        """

        self.sfm_member_point_up_to_limit.Limit = value.com_object

    @property
    def point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Point() As Reference
                | 
                |     Returns or sets the point.
                |     Sub-element(s) supported (see Boundary object): Vertex.
                | 
                |     Example:
                |         This example retrieves in Point the point for the
                |         SfmMemberPointUpToLimit feature.
                | 
                |          Dim Point As Reference
                |          Set Point = SfmMemberPointUpToLimit.Point

        :rtype: Reference
        """

        return Reference(self.sfm_member_point_up_to_limit.Point)

    @point.setter
    def point(self, value: Reference):
        """
        :param Reference value:
        """

        self.sfm_member_point_up_to_limit.Point = value.com_object

    def invert_direction(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub InvertDirection()
                | 
                |     Inverts the direction orientation.
                | 
                |     Example:
                |         This example inverts the orientation of the direction for the
                |         SfmMemberPointUpToLimit feature.
                | 
                |          SfmMemberPointUpToLimit.InvertDirection

        :rtype: None
        """
        return self.sfm_member_point_up_to_limit.InvertDirection()

    def __repr__(self):
        return f'SFMMemberPointUpToLimit(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class StrAnchorPoint(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     StrAnchorPoint
                | 
                | Represents an anchor point.
                | An anchor point is a point used to place the section on the support in the
                | design model.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.str_anchor_point = com_object

    def get_coordinates(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetCoordinates(CATSafeArrayVariant oCoord)
                | 
                |     Retrieves the coordinates of the anchor point. These coordinates are
                |     expressed in the section local coordinate system.
                | 
                |     Parameters:
                | 
                |         oCoord
                |             The 2D coordinates of the anchor point. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim coord(1)
                |          anchor_1.GetCoordinates(coord)

        :param tuple o_coord:
        :rtype: None
        """
        return self.str_anchor_point.GetCoordinates()
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_coordinates'
        # # vba_code = """
        # # Public Function get_coordinates(str_anchor_point)
        # #     Dim oCoord (2)
        # #     str_anchor_point.GetCoordinates oCoord
        # #     get_coordinates = oCoord
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'StrAnchorPoint(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.reference import Reference
from pycatia.product_structure_interfaces.product import Product
from pycatia.product_structure_interfaces.publication import Publication
from pycatia.system_interfaces.any_object import AnyObject


class ABQOutputRequest(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQOutputRequest
                | 
                | Represents the base interface for all output request objects.
                | Role: The ABQOutputRequest interface manages the common attributes of any
                | output requests.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_output_request = com_object

    @property
    def activation_status(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ActivationStatus() As boolean
                | 
                |     Sets or returns the activation status.
                | 
                |     Returns:
                |         A boolean specifying whether the output request is activated or
                |         deactivated.

        :rtype: bool
        """

        return self.abq_output_request.ActivationStatus

    @activation_status.setter
    def activation_status(self, value: bool):
        """
        :param bool value:
        """

        self.abq_output_request.ActivationStatus = value

    @property
    def num_increment_frequency(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NumIncrementFrequency(long iNumIncrementFrequency) (Write
                | Only)
                | 
                |     Sets request for output results at specified increment.

        :rtype: int
        """

        return self.abq_output_request.NumIncrementFrequency

    @num_increment_frequency.setter
    def num_increment_frequency(self, value: int):
        """
        :param int value:
        """

        self.abq_output_request.NumIncrementFrequency = value

    @property
    def status(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Status() As CATBSTR (Read Only)
                | 
                |     Returns the propagating status of the output request.
                | 
                |     Returns:
                |         The propagating status for example: if the output request feature is
                |         created, it will return "CREATED" if the output request feature is propagated
                |         from previous step, it will return "PROPAGATED" if the output request feature
                |         is modified in current step, it will return "MODIFIED"

        :rtype: str
        """

        return self.abq_output_request.Status

    @property
    def type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As CATBSTR (Read Only)
                | 
                |     Returns the type of the output request.
                | 
                |     Returns:
                |         The string representing the type of the output request.

        :rtype: str
        """

        return self.abq_output_request.Type

    @property
    def whole_model_as_supp(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WholeModelAsSupp() As boolean
                | 
                |     Sets or returns whether the whole model is selected as support. A value of
                |     true indicates that the whole model is selected as
                |     support.
                | 
                |     Returns:
                |         A boolean specifying whether the whole model is selected as support.

        :rtype: bool
        """

        return self.abq_output_request.WholeModelAsSupp

    @whole_model_as_supp.setter
    def whole_model_as_supp(self, value: bool):
        """
        :param bool value:
        """

        self.abq_output_request.WholeModelAsSupp = value

    def add_support_from_product(self, i_product: Product, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromProduct(Product iProduct,
                | Reference iSupport)
                | 
                |     Creates a new support and adds it to the description of the Analysis
                |     Entity.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIA Product specifying the object to which the output request
                |             is applied.
                |         iSupport
                |             The CATIA Reference specifying the region to which the output
                |             request is applied.
                | 
                |             Refer: CATIAReference , CATIAProduct

        :param Product i_product:
        :param Reference i_support:
        :rtype: None
        """
        return self.abq_output_request.AddSupportFromProduct(i_product.com_object, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_product'
        # # vba_code = """
        # # Public Function add_support_from_product(abq_output_request)
        # #     Dim iProduct (2)
        # #     abq_output_request.AddSupportFromProduct iProduct
        # #     add_support_from_product = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_from_publication(self, i_product: Product, i_publication: Publication) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromPublication(Product iProduct,
                | Publication iPublication)
                | 
                |     Creates a new support and adds it to the description of the Analysis
                |     Entity.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIA Product specifying the object to which the output request
                |             is applied.
                |         iPublication
                |             The CATIA Publication specifying the region to which the output
                |             request is applied.
                | 
                |             Refer: CATIAPublication

        :param Product i_product:
        :param Publication i_publication:
        :rtype: None
        """
        return self.abq_output_request.AddSupportFromPublication(i_product.com_object, i_publication.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_publication'
        # # vba_code = """
        # # Public Function add_support_from_publication(abq_output_request)
        # #     Dim iProduct (2)
        # #     abq_output_request.AddSupportFromPublication iProduct
        # #     add_support_from_publication = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_from_reference(self, i_reference: Reference, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromReference(Reference iReference,
                | Reference iSupport)
                | 
                |     Creates a new support and adds it to the description of the Analysis
                |     Entity.
                | 
                |     Parameters:
                | 
                |         iReference
                |             The CATIA Reference specifying the object to which the output
                |             request is applied.
                |         iSupport
                |             The CATIA Reference specifying the region to which the output
                |             request is applied.
                | 
                |             Refer: CATIAReference

        :param Reference i_reference:
        :param Reference i_support:
        :rtype: None
        """
        return self.abq_output_request.AddSupportFromReference(i_reference.com_object, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_reference'
        # # vba_code = """
        # # Public Function add_support_from_reference(abq_output_request)
        # #     Dim iReference (2)
        # #     abq_output_request.AddSupportFromReference iReference
        # #     add_support_from_reference = iReference
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_output_at_last_increment(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOutputAtLastIncrement()
                | 
                |     Sets request for output results at last increment.

        :rtype: None
        """
        return self.abq_output_request.SetOutputAtLastIncrement()

    def __repr__(self):
        return f'ABQOutputRequest(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.parameter import Parameter
from pycatia.product_structure_interfaces.product import Product


class StrObject(Product):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ProductStructureInterfaces.Product
                |                         StrObject
                | 
                | Represents a structure object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.str_object = com_object

    @property
    def type_(self) -> Parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As Parameter (Read Only)
                | 
                |     Returns the type of the structure object.
                | 
                |     Example:
                |         This example retrieves the type of the StructureMember
                |         object.
                | 
                |          Dim oType As Parameter
                |          Set oType = StructureMember.Type

        :rtype: Parameter
        """

        return Parameter(self.str_object.Type)

    def __repr__(self):
        return f'StrObject(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_component import SchComponent
from pycatia.cat_sch_platform_interfaces.sch_grr_comp import SchGRRComp
from pycatia.system_interfaces.any_object import AnyObject


class SchReplace(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchReplace
                | 
                | Manage existing schematic component instances.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_replace = com_object

    def replace(self, i_grr_to_be_placed: SchGRRComp, i_sch_comp_to_be_removed: SchComponent) -> SchComponent:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Replace(SchGRRComp iGRRToBePlaced,
                | SchComponent iSchCompToBeRemoved) As SchComponent
                | 
                |     Replace an existing component with this component.
                | 
                |     Parameters:
                | 
                |         iGRRToBePlaced
                |             Pointer to the component graphical representation of this component
                |             to be placed. if NULL the first representation found will be used.
                |             
                |         iSchCompToBeRemoved
                |             Pointer to the existing component to be replaced by this component.
                |             
                |         oNewComponent
                |             Interface pointer to the new component instance placed.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchReplace
                |          Dim objArg1 As SchGRRComp
                |          Dim objArg2 As SchComponent
                |          Dim objArg3 As SchComponent
                |           ...
                |          Set objArg3 = objThisIntf.Replace(objArg1,objArg2)

        :param SchGRRComp i_grr_to_be_placed:
        :param SchComponent i_sch_comp_to_be_removed:
        :rtype: SchComponent
        """
        return SchComponent(
            self.sch_replace.Replace(
                i_grr_to_be_placed.com_object,
                i_sch_comp_to_be_removed.com_object
            )
        )

    def __repr__(self):
        return f'SchReplace(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.manufacturing_interfaces.manufacturing_feature import ManufacturingFeature
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ManufacturingFeatures(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ManufacturingFeatures
                | 
                | Collection of Manufacturing Features.
                | 
                | See also:
                |     ManufacturingFeature
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_features = com_object

    def add(self, i_type: str) -> ManufacturingFeature:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(CATBSTR iType) As ManufacturingFeature
                | 
                |     Create and Add a Manufacturing Feature of a specified type to the
                |     Collection.
                | 
                |     Example:
                |         The following example creates and adds in Features the manufacturing feature Feature of type : type
                | 
                |          Set Feature = Features.Add(Type)

        :param str i_type:
        :rtype: ManufacturingFeature
        """
        return ManufacturingFeature(self.manufacturing_features.Add(i_type))

    def item(self, i_index: cat_variant) -> ManufacturingFeature:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ManufacturingFeature
                | 
                |     Retrieve the Manufacturing Feature of a the specified index from the
                |     Collection.
                | 
                |     Example:
                |         The following example retrieves from Feature the manufacturing feature Feature from index : Index
                | 
                |          Set Feature = Features.Item(Index)

        :param cat_variant i_index:
        :rtype: ManufacturingFeature
        """
        return ManufacturingFeature(self.manufacturing_features.Item(i_index))

    def __repr__(self):
        return f'ManufacturingFeatures(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_job import ABQJob
from pycatia.in_interfaces.reference import Reference
from pycatia.product_structure_interfaces.product import Product
from pycatia.product_structure_interfaces.publication import Publication
from pycatia.system_interfaces.any_object import AnyObject


class ABQTemperature(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQTemperature
                | 
                | Represents an Abaqus temperature object (ABQTemperature).
                | Role: Access an Abaqus temperature object or determine its properties. It has
                | common properties of ABQInitialTemperature,
                | ABQTemperatureHistory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_temperature = com_object

    @property
    def apply_user_subroutine(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ApplyUserSubroutine() As boolean
                | 
                |     Sets or returns the user subroutine flag.
                | 
                |     Returns:
                |         A boolean specifying whether a user subroutine will be
                |         applied.

        :rtype: bool
        """

        return self.abq_temperature.ApplyUserSubroutine

    @apply_user_subroutine.setter
    def apply_user_subroutine(self, value: bool):
        """
        :param bool value:
        """

        self.abq_temperature.ApplyUserSubroutine = value

    @property
    def distribution(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Distribution() As Distribution_Type
                | 
                |     Sets or returns the distribution type associated with this temperature
                |     field.
                | 
                |       
                |     Legal values:
                |      UNIFORM
                |      JOB 
                |      USERDEFINED 
                |      JOB_USERDEFINED
                |      
                | 
                |     Example:
                |         This example sets the distribution type to
                |         USERDEFINED.
                | 
                |          Dim abqTemperature As ABQTemperature
                |          abqTemperature.Distribution = USERDEFINED

        :return: enum distribution_type
        :rtype: int
        """

        return self.abq_temperature.Distribution

    @distribution.setter
    def distribution(self, value: int):
        """
        :param int value:
        """

        self.abq_temperature.Distribution = value

    @property
    def job(self) -> ABQJob:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Job() As ABQJob
                | 
                |     Sets or returns the Abaqus job associated with this temperature field. *
                |     The job being attached to the temperature field must belong to a thermal case
                |     and must not belong to same analysis case to which the temperature field
                |     belongs.
                | 
                |     Example:
                |         This example retrieves the ABQJob abqJob.
                | 
                |          Dim abqTemperature As ABQTemperature
                |          Dim abqJob As ABQJob 
                |          Set abqJob = abqTemperature.Job

        :rtype: ABQJob
        """

        return ABQJob(self.abq_temperature.Job)

    @job.setter
    def job(self, value: ABQJob):
        """
        :param ABQJob value:
        """

        self.abq_temperature.Job = value

    @property
    def magnitude(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Magnitude() As double
                | 
                |     Sets or returns the magnitude of the temperature field.
                | 
                |     Returns:
                |         The magnitude of the temperature field.

        :rtype: float
        """

        return self.abq_temperature.Magnitude

    @magnitude.setter
    def magnitude(self, value: float):
        """
        :param float value:
        """

        self.abq_temperature.Magnitude = value

    @property
    def type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As CATBSTR (Read Only)
                | 
                |     Returns the type of the Temperature.
                | 
                |     Returns:
                |         The type of the Temperature.

        :rtype: str
        """

        return self.abq_temperature.Type

    def add_support_from_product(self, i_product: Product, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromProduct(Product iProduct,
                | Reference iSupport)
                | 
                |     This adds the support from a product to the Field.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIA Product specifying the object to which the field is
                |             applied.
                |         iSupport
                |             The CATIA Reference specifying the region to which the field is
                |             applied.
                |             Refer: CATIAReference , CATIAProduct

        :param Product i_product:
        :param Reference i_support:
        :rtype: None
        """
        return self.abq_temperature.AddSupportFromProduct(i_product.com_object, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_product'
        # # vba_code = """
        # # Public Function add_support_from_product(abq_temperature)
        # #     Dim iProduct (2)
        # #     abq_temperature.AddSupportFromProduct iProduct
        # #     add_support_from_product = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_from_publication(self, i_product: Product, i_publication: Publication) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromPublication(Product iProduct,
                | Publication iPublication)
                | 
                |     Creates a new support and adds it to the description of the Analysis
                |     Entity.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIA Product specifying the object to which the field is
                |             applied.
                |         iPublication
                |             The CATIA Publication specifying the region to which the field is
                |             applied.
                | 
                |             Refer: CATIAPublication

        :param Product i_product:
        :param Publication i_publication:
        :rtype: None
        """
        return self.abq_temperature.AddSupportFromPublication(i_product.com_object, i_publication.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_publication'
        # # vba_code = """
        # # Public Function add_support_from_publication(abq_temperature)
        # #     Dim iProduct (2)
        # #     abq_temperature.AddSupportFromPublication iProduct
        # #     add_support_from_publication = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQTemperature(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.kinematics_interfaces.joint import Joint
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Joints(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Joints
                | 
                | A collection of all Joint entities currently managed by the
                | application.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Joint)
        self.joints = com_object

    def add(self) -> Joint:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add() As Joint
                | 
                |     Create a new Joint and adds it to the Joints collection.
                | 
                |     Returns:
                |         The created Joint 
                |     Example:
                |         This example creates a new Joint in the TheJoints
                |         collection.
                | 
                |             Dim NewJoint As Joint
                |             Set NewJoint = TheJoints.Add()

        :rtype: Joint
        """
        return Joint(self.joints.Add())

    def item(self, i_index: cat_variant) -> Joint:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As Joint
                | 
                |     Returns a Joint using its index or its name from the Joints
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Joint to retrieve from the collection
                |             of Joints. As a numerics, this index is the rank of the Joint in the
                |             collection. The index of the first Joint in the collection is 1, and the index
                |             of the last Joint is Count. As a string, it is the name you assigned to the
                |             Joint using the 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved Joint 
                |     Example:
                |         This example returns in ThisJoint the third Joint in the collection,
                |         and in ThatJoint the Joint named MyJoint.
                | 
                |          Dim ThisJoint As Joint
                |          Set ThisJoint = TheJoints.Item(3)
                |          Dim ThatJoint As Joint
                |          Set ThatJoint = CATIA.Joints.Item("MyJoint")

        :param cat_variant i_index:
        :rtype: Joint
        """
        return Joint(self.joints.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Remove a Joint from the Joints collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Joint to retrieve from the collection
                |             of Joints. As a numerics, this index is the rank of the Joint in the
                |             collection. The index of the first Joint in the collection is 1, and the index
                |             of the last Joint is Count. As a string, it is the name you assigned to the
                |             Joint. 
                | 
                |     Returns:
                |         Nothing 
                |     Example:
                |         The following example removes the tenth Joint and the Joint named
                |         JointTwo from the TheJoints collection.
                | 
                |             TheJoints.Remove(10)
                |             TheJoints.Remove("JointTwo")

        :param cat_variant i_index:
        :rtype: None
        """
        return self.joints.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(joints)
        # #     Dim iIndex (2)
        # #     joints.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Joints(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchObsoleteModel(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchObsoleteModel
                | 
                | Manage obsolete model elements.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_obsolete_model = com_object

    def find_obsolete_classes(self) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func FindObsoleteClasses() As SchListOfObjects
                | 
                |     Find obsolete base classes. This method will internally call
                |     CATISchAppObsoleteClass to ask the application for the names of the obsolete
                |     classes.
                | 
                |     Parameters:
                | 
                |         oListObsoleteObj
                |             A list of objects with obsoleted base class types.
                |             
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchObsoleteModel
                |          Dim objArg1 As SchListOfObjects
                |           ...
                |          Set objArg1 = objThisIntf.FindObsoleteClasses

        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.sch_obsolete_model.FindObsoleteClasses())

    def has_obsolete_class(self, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub HasObsoleteClass(boolean oBYes)
                | 
                |     Is there any obsolete class in the application model.
                | 
                |     Parameters:
                | 
                |         oBYes
                |             If yes, then there is. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchObsoleteModel
                |          Dim bVar1 As boolean
                |           ...
                |          objThisIntf.HasObsoleteClassbVar1

        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_obsolete_model.HasObsoleteClass(o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'has_obsolete_class'
        # # vba_code = """
        # # Public Function has_obsolete_class(sch_obsolete_model)
        # #     Dim oBYes (2)
        # #     sch_obsolete_model.HasObsoleteClass oBYes
        # #     has_obsolete_class = oBYes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchObsoleteModel(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_human_sim_interfaces.human_task import HumanTask
from pycatia.system_interfaces.collection import Collection


class HumanTaskList(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     HumanTaskList

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.human_task_list = com_object

    def item(self, i_index: int) -> HumanTask:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(long iIndex) As HumanTask
                | 
                |     Returns the HumanTask of the specified index from
                |     HumanTaskList
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The task index

        :param int i_index:
        :rtype: HumanTask
        """
        return HumanTask(self.human_task_list.Item(i_index))

    def remove(self, i_index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(long iIndex)
                | 
                |     This method removes the specified HumanTask on the current
                |     TaskList
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The task index

        :param int i_index:
        :rtype: None
        """
        return self.human_task_list.Remove(i_index)

    def __repr__(self):
        return f'HumanTaskList(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeFill(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeFill
                | 
                | The Fill feature : an Fill is made up of a face to process and one Fill parameter.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_fill = com_object

    @property
    def advanced_tolerant_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AdvancedTolerantMode() As long
                | 
                |     Returns or sets the tolerant mode taken into account during fill
                |     construction.
                |     Legal values:
                | 
                |     0
                |         Unknown tolerant mode.
                |     1
                |         None tolerant mode. Error thrown if maximum deviation exceeds CATIA
                |         resolution.
                |     2
                |         Automatic tolerant mode. Error thrown if maximum deviation exceeds 100
                |         times CATIA resolution.
                |     3
                |         Manual tolerant mode. Error thrown if maximum deviation exceeds input
                |         user deviation.
                | 
                |     Example:
                |         This example retrieves in oMode the tolerant mode for the Fill hybrid
                |         shape feature.
                | 
                |          Dim oMode
                |          Set oMode = Fill.AdvancedTolerantMode

        :rtype: int
        """

        return self.hybrid_shape_fill.AdvancedTolerantMode

    @advanced_tolerant_mode.setter
    def advanced_tolerant_mode(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_fill.AdvancedTolerantMode = value

    @property
    def constraint(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Constraint() As Reference
                | 
                |     Returns or sets the passing point for the Fill.
                | 
                |     Example:
                |         This example retrieves in Element the passing point for the Fill hybrid
                |         shape feature.
                | 
                |          Dim Element As Reference 
                |          Set Element = Fill.Constraint

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_fill.Constraint)

    @constraint.setter
    def constraint(self, reference: Reference):
        """
        :param Reference reference:
        """

        self.hybrid_shape_fill.Constraint = reference.com_object

    @property
    def continuity(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Continuity() As long
                | 
                |     Returns or sets the continuity between the support and
                |     fill.
                |     Legal values:
                | 
                |     0
                |         Continuity in point (C0)
                |     1
                |         Continuity in tangency (C1)
                |     2
                |         Continuity in curvature (C2)
                | 
                |     Example:
                |         This example retrieves in oContinuity the continuity type for the Fill
                |         hybrid shape feature.
                | 
                |          Dim oContinuity
                |          Set oContinuity = Fill.Continuity

        :rtype: int
        """

        return self.hybrid_shape_fill.Continuity

    @continuity.setter
    def continuity(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_fill.Continuity = value

    @property
    def detection(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Detection() As short
                | 
                |     Returns or sets the Canonical portion detection option.
                |     Legal values:
                | 
                |     0
                |         No detection of canonical surface
                |     2
                |         Detection of canonical surfaces

        :rtype: int
        """

        return self.hybrid_shape_fill.Detection

    @detection.setter
    def detection(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_fill.Detection = value

    @property
    def maximum_deviation_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MaximumDeviationValue() As double
                | 
                |     Sets or Gets the maximum deviation allowed for smoothing operation in fill
                |     commnd. This value must be set in SI unit (m).
                | 
                |     Example: This example retrieves in DeviationValue the maximum deviation
                |     value for the Fill hybrid shape feature.
                | 
                |      Dim DeviationValue As double
                |      Set DeviationValue = Fill.MaximumDeviationValue

        :rtype: float
        """

        return self.hybrid_shape_fill.MaximumDeviationValue

    @maximum_deviation_value.setter
    def maximum_deviation_value(self, value: float):
        """
        :param float value:
        """

        self.hybrid_shape_fill.MaximumDeviationValue = value

    @property
    def plane_only_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PlaneOnlyMode() As boolean
                | 
                |     Returns or sets whether Planar Boundaries only should be considered during
                |     fill operation.
                |     Legal values:
                | 
                |     TRUE
                |         Planar boundaries are only considered during Fill
                |         operation
                |     FALSE
                |         Non-Planar boundaries are also considered during Fill
                |         operation

        :rtype: bool
        """

        return self.hybrid_shape_fill.PlaneOnlyMode

    @plane_only_mode.setter
    def plane_only_mode(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_fill.PlaneOnlyMode = value

    @property
    def tolerant_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property TolerantMode() As boolean
                | 
                |     Deprecated:
                |         V5R26 Use HybridShapeFill.AdvancedTolerantMode Returns or sets the Tolerant mode option.
                |         Role: To activate or not the tolerant mode option TRUE : Tolerant mode is active.
                |         Uses deviation parameter to do tolerant fill. FALSE : Tolerant mode is not active.
                | 
                |         Example: This example retrieves in tolMode the tolerant mode for the
                |         Fill hybrid shape feature.
                | 
                |          Dim tolMode As boolean
                |          Set tolMode = Fill.TolerantMode

        :rtype: bool
        """

        return self.hybrid_shape_fill.TolerantMode

    @tolerant_mode.setter
    def tolerant_mode(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_fill.TolerantMode = value

    def add_bound(self, i_boundary: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddBound(Reference iBoundary)
                | 
                |     Adds an boundary to the hybrid shape fill feature object.
                | 
                |     Parameters:
                | 
                |         iBoundary
                |             The boundary(curve) to be added to the hybrid shape fill feature
                |             object. 
                | 
                |     Example:
                |         The following example adds the iBoundary curve to the Fill
                |         object.
                | 
                |          Fill.AddBound iBoundary

        :param Reference i_boundary:
        :rtype: None
        """
        return self.hybrid_shape_fill.AddBound(i_boundary.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_bound'
        # # vba_code = """
        # # Public Function add_bound(hybrid_shape_fill)
        # #     Dim iBoundary (2)
        # #     hybrid_shape_fill.AddBound iBoundary
        # #     add_bound = iBoundary
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_at_bound(self, i_boundary: Reference, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddSupportAtBound(Reference iBoundary,
                | Reference iSupport)
                | 
                |     Inserts the support at specified boundary in the Fill.
                | 
                |     Parameters:
                | 
                |         iBoundary
                |             Reference of the boundary object to which support has to be added.
                |             
                |         iSupport
                |             Reference of the support object to be added.
                | 
                |             Example:
                |                 This example adds supports in the Fill feature Fill to
                |                 specified iBoundary boundary
                | 
                |                  Fill.AddSupportAtBound iBoundary,iSupport

        :param Reference i_boundary:
        :param Reference i_support:
        :rtype: None
        """
        return self.hybrid_shape_fill.AddSupportAtBound(i_boundary.com_object, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_at_bound'
        # # vba_code = """
        # # Public Function add_support_at_bound(hybrid_shape_fill)
        # #     Dim iBoundary (2)
        # #     hybrid_shape_fill.AddSupportAtBound iBoundary
        # #     add_support_at_bound = iBoundary
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def append_constraint(self, i_constraint: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AppendConstraint(Reference iConstraint)
                | 
                |     Appends an constraint to the hybrid shape fill feature object. ========
                |     ONLY USE IN FSS ==============
                | 
                |     Parameters:
                | 
                |         iConstraint
                |             The constraint to be appended. 
                | 
                |     Example:
                |         The following example appends the iConstraint constraint to the Fill
                |         object.
                | 
                |          Fill.AppendConstraint iConstraint

        :param Reference i_constraint:
        :rtype: None
        """
        return self.hybrid_shape_fill.AppendConstraint(i_constraint.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'append_constraint'
        # # vba_code = """
        # # Public Function append_constraint(hybrid_shape_fill)
        # #     Dim iConstraint (2)
        # #     hybrid_shape_fill.AppendConstraint iConstraint
        # #     append_constraint = iConstraint
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_bound_at_position(self, i_pos: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetBoundAtPosition(long iPos) As Reference
                | 
                |     Retrieves the boundary at specified position in the hybrid shape fill
                |     feature object.
                | 
                |     Parameters:
                | 
                |         iPos
                |             The position of the boundary to retrieve. 
                | 
                |     Example:
                |         The following example gets the oBoundary boundary of the Fill object at
                |         the position iPos.
                | 
                |          Dim oBoundary As Reference
                |          Set oBoundary = Fill.GetBoundAtPosition (iPos).

        :param int i_pos:
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_fill.GetBoundAtPosition(i_pos))

    def get_bound_position(self, i_boundary: Reference) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetBoundPosition(Reference iBoundary) As long
                | 
                |     Retrieves the position of a boundary used by the hybrid shape fill feature
                |     object.
                | 
                |     Parameters:
                | 
                |         iBoundary
                |             The boundary whose position has to be retrieved. 
                | 
                |     Example:
                |         The following example gets the oPos position of the iBoundary boundary
                |         in the Fill object.
                | 
                |          Dim oPos As  long
                |          oPos = Fill.GetBoundPosition (iBoundary).

        :param Reference i_boundary:
        :rtype: int
        """
        return self.hybrid_shape_fill.GetBoundPosition(i_boundary.com_object)

    def get_bound_size(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetBoundSize() As long
                | 
                |     Returns the number of boundaries in the Fill object.
                | 
                |     Parameters:
                | 
                |         oSize
                |             Number of boundaries in the Fill.
                | 
                |             Example:
                |                 This example retrieves the number of boundaries in the Fill
                |                 hybrid shape fill.
                | 
                |                  Dim oSize As  long
                |                  oSize = Fill.GetBoundSize

        :rtype: int
        """
        return self.hybrid_shape_fill.GetBoundSize()

    def get_boundary_continuity(self, i_pos: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetBoundaryContinuity(long iPos) As long
                | 
                |     Returns the continuity mode for a boundary at specified position in the
                |     Fill.
                | 
                |     Parameters:
                | 
                |         iPos
                |             Position at which the continuity should be retrieved.
                |             
                |         oContinuity
                |             Continuity retrieved between the support and the
                |             fill.
                |             Legal values:
                | 
                |             0
                |                 Continuity in point (C0)
                |             1
                |                 Continuity in tangency (C1)
                |             2
                |                 Continuity in curvature (C2)
                | 
                |     Example:
                |         This example retrieves in oContinuity the continuity at the specified
                |         position of Fill hybrid shape fill feature.
                | 
                |          oContinuity = Fill.GetBoundaryContinuity iPos

        :param int i_pos:
        :rtype: int
        """
        return self.hybrid_shape_fill.GetBoundaryContinuity(i_pos)

    def get_constraint_at_position(self, i_pos: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetConstraintAtPosition(long iPos) As Reference
                | 
                |     Retrieves the constraint at specified position in the hybrid shape fill
                |     feature object. ======== ONLY USE IN FSS ==============
                | 
                |     Parameters:
                | 
                |         iPos
                |             The position of the constraint to retrieve. 
                | 
                |     Example:
                |         The following example gets the oConstraint constraint of the Fill
                |         object at the position iPos.
                | 
                |          Dim oConstraint As Reference
                |          Set oConstraint = Fill.GetConstraintAtPosition (iPos).

        :param int i_pos:
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_fill.GetConstraintAtPosition(i_pos))

    def get_constraints_size(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetConstraintsSize() As long
                | 
                |     Returns the number of constraints in the Fill object.
                | 
                |     Parameters:
                | 
                |         oSize
                |             Number of constraints in the Fill.
                | 
                |             Example:
                |                 This example retrieves the number of constraints in the Fill
                |                 hybrid shape fill.
                | 
                |                  Dim oSize As  long
                |                  oSize = Fill.GetConstraintsSize

        :rtype: int
        """
        return self.hybrid_shape_fill.GetConstraintsSize()

    def get_support_at_position(self, i_pos: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetSupportAtPosition(long iPos) As Reference
                | 
                |     Retrieves the support at specified position in the hybrid shape fill
                |     feature object.
                | 
                |     Parameters:
                | 
                |         iPos
                |             The position of the support to retrieve. 
                | 
                |     Example:
                |         The following example gets the oSupport support of the Fill object at
                |         the position iPos.
                | 
                |          Dim oSupport As Reference
                |          Set oSupport = Fill.GetSupportAtPosition (iPos).

        :param int i_pos:
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_fill.GetSupportAtPosition(i_pos))

    def insert_bound_after_position(self, i_boundary: Reference, i_pos: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub InsertBoundAfterPosition(Reference iBoundary,
                | long iPos)
                | 
                |     Inserts the boundary after specified position in the Fill.
                | 
                |     Parameters:
                | 
                |         iBoundary
                |             Reference of the boundary object to be inserted. 
                |         iPos
                |             Position after which the element should be
                |             inserted.
                | 
                |             Example:
                |                 This example inserts the boundary in the Fill feature Fill
                |                 after position iPos
                | 
                |                  Fill.InsertBoundAfterPosition iBoundary,iPos

        :param Reference i_boundary:
        :param int i_pos:
        :rtype: None
        """
        return self.hybrid_shape_fill.InsertBoundAfterPosition(i_boundary.com_object, i_pos)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'insert_bound_after_position'
        # # vba_code = """
        # # Public Function insert_bound_after_position(hybrid_shape_fill)
        # #     Dim iBoundary (2)
        # #     hybrid_shape_fill.InsertBoundAfterPosition iBoundary
        # #     insert_bound_after_position = iBoundary
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_all_bound(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveAllBound()
                | 
                |     Removes all boundaries of the hybrid shape fill feature object.
                |     
                | 
                | Example:
                |     The following example removes all boundaries of the Fill
                |     object.
                | 
                |      Fill.RemoveAllBound

        :rtype: None
        """
        return self.hybrid_shape_fill.RemoveAllBound()

    def remove_all_constraints(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveAllConstraints()
                | 
                |     Removes all constraints.

        :rtype: None
        """
        return self.hybrid_shape_fill.RemoveAllConstraints()

    def remove_bound_at_position(self, i_pos: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveBoundAtPosition(long iPos)
                | 
                |     Removes boundary at specified position in hybrid shape fill feature
                |     object.
                | 
                |     Parameters:
                | 
                |         iPos
                |             The position of the boundary to remove. 
                | 
                |     Example:
                |         The following example removes the boundary object from the Fill object
                |         at the position iPos.
                | 
                |          Fill.RemoveBoundAtPosition iPos.

        :param int i_pos:
        :rtype: None
        """
        return self.hybrid_shape_fill.RemoveBoundAtPosition(i_pos)

    def remove_constraint(self, i_pos: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveConstraint(long iPos)
                | 
                |     Removes constraint at specified position in hybrid shape fill feature
                |     object. ======== ONLY USE IN FSS ==============
                | 
                |     Parameters:
                | 
                |         iPos
                |             The position of the constraint to remove. 
                | 
                |     Example:
                |         The following example removes the constraint object from the Fill
                |         object at the position iPos.
                | 
                |          Fill.RemoveConstraint iPos.

        :param int i_pos:
        :rtype: None
        """
        return self.hybrid_shape_fill.RemoveConstraint(i_pos)

    def remove_support_at_position(self, i_pos: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveSupportAtPosition(long iPos)
                | 
                |     Removes support at specified position in hybrid shape fill feature
                |     object.
                | 
                |     Parameters:
                | 
                |         iPos
                |             The position of the support to remove. 
                | 
                |     Example:
                |         The following example removes the support object from the Fill object
                |         at the position iPos.
                | 
                |          Fill.RemoveSupportAtPosition iPos.

        :param int i_pos:
        :rtype: None
        """
        return self.hybrid_shape_fill.RemoveSupportAtPosition(i_pos)

    def replace_bound_at_position(self, i_boundary: Reference, i_pos: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub ReplaceBoundAtPosition(Reference iBoundary,
                | long iPos)
                | 
                |     Replaces the boundary at specified position in the Fill.
                | 
                |     Parameters:
                | 
                |         iBoundary
                |             Reference of the boundary object to be replaced. 
                |         iPos
                |             Position at which the boundary should be replaced.
                | 
                |             Example:
                |                 This example replaces the boundary in the Fill feature Fill at
                |                 specified position iPos
                | 
                |                  Fill.ReplaceBoundAtPosition iBoundary,iPos

        :param Reference i_boundary:
        :param int i_pos:
        :rtype: None
        """
        return self.hybrid_shape_fill.ReplaceBoundAtPosition(i_boundary.com_object, i_pos)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'replace_bound_at_position'
        # # vba_code = """
        # # Public Function replace_bound_at_position(hybrid_shape_fill)
        # #     Dim iBoundary (2)
        # #     hybrid_shape_fill.ReplaceBoundAtPosition iBoundary
        # #     replace_bound_at_position = iBoundary
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def replace_constraint(self, i_pos: int, i_constraint: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub ReplaceConstraint(long iPos,
                | Reference iConstraint)
                | 
                |     Replaces the constraint at specified position in the Fill.
                | 
                |     Parameters:
                | 
                |         iPos
                |             Position at which the constraint should be replaced.
                |             
                |         iConstraint
                |             Reference of the constraint object to be replaced.
                | 
                |             Example:
                |                 This example replaces the constraint in the Fill feature Fill
                |                 at specified position iPos
                | 
                |                  Fill.ReplaceConstraint iPos,iConstraint

        :param int i_pos:
        :param Reference i_constraint:
        :rtype: None
        """
        return self.hybrid_shape_fill.ReplaceConstraint(i_pos, i_constraint.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'replace_constraint'
        # # vba_code = """
        # # Public Function replace_constraint(hybrid_shape_fill)
        # #     Dim iPos (2)
        # #     hybrid_shape_fill.ReplaceConstraint iPos
        # #     replace_constraint = iPos
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def replace_support_at_position(self, i_support: Reference, i_pos: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub ReplaceSupportAtPosition(Reference iSupport,
                | long iPos)
                | 
                |     Replaces the support at specified position in the Fill.
                | 
                |     Parameters:
                | 
                |         iSupport
                |             Reference of the support object to be replaced. 
                |         iPos
                |             Position at which the support should be replaced.
                | 
                |             Example:
                |                 This example replaces the support in the Fill feature Fill at
                |                 specified position iPos
                | 
                |                  Fill.ReplaceSupportAtPosition iSupport,iPos

        :param Reference i_support:
        :param int i_pos:
        :rtype: None
        """
        return self.hybrid_shape_fill.ReplaceSupportAtPosition(i_support.com_object, i_pos)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'replace_support_at_position'
        # # vba_code = """
        # # Public Function replace_support_at_position(hybrid_shape_fill)
        # #     Dim iSupport (2)
        # #     hybrid_shape_fill.ReplaceSupportAtPosition iSupport
        # #     replace_support_at_position = iSupport
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_boundary_continuity(self, i_continuity: int, i_pos: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetBoundaryContinuity(long iContinuity,
                | long iPos)
                | 
                |     Sets the continuity mode for a boundary at specified position in the
                |     Fill.
                | 
                |     Parameters:
                | 
                |         iContinuity
                |             Continuity between the support and the fill.
                |             Legal values:
                | 
                |             0
                |                 Continuity in point (C0)
                |             1
                |                 Continuity in tangency (C1)
                |             2
                |                 Continuity in curvature (C2)
                | 
                |         iPos
                |             Position at which the continuity should be set.
                | 
                |             Example:
                |                 This example sets the continuity in the Fill feature Fill at
                |                 specified position iPos
                | 
                |                  Fill.SetBoundaryContinuity iContinuity,iPos

        :param int i_continuity:
        :param int i_pos:
        :rtype: None
        """
        return self.hybrid_shape_fill.SetBoundaryContinuity(i_continuity, i_pos)

    def __repr__(self):
        return f'HybridShapeFill(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_mass_scaling import ABQMassScaling
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ABQMassScalings(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ABQMassScalings
                | 
                | Represents a collection of
                | ABQMassScaling entries.
                | Role:
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ABQMassScaling)
        self.abq_mass_scalings = com_object

    def add(self) -> ABQMassScaling:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add() As ABQMassScaling
                | 
                |     Adds a new ABQMassScaling to the collection.
                | 
                |     Returns:
                |         The created ABQMassScaling entry.

        :rtype: ABQMassScaling
        """
        return ABQMassScaling(self.abq_mass_scalings.Add())

    def item(self, i_index: cat_variant) -> ABQMassScaling:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ABQMassScaling
                | 
                |     Returns the ABQMassScaling entry for the specified index.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the ABQMassScaling to retrieve. If the
                |             index is a number, it specifies the element offset within the collection. The
                |             offset starts at 1. If the index is a string, it specifies the name
                |             (MassScaling.Name property) of the desired
                |             element.

        :param cat_variant i_index:
        :rtype: ABQMassScaling
        """
        return ABQMassScaling(self.abq_mass_scalings.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes the specified entry.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the ABQMassScaling to remove. If the index
                |             is a number, it specifies the element offset within the collection. The offset
                |             starts at 1. If the index is a string, it specifies the name (MassScaling.Name
                |             property) of the desired element.

        :param cat_variant i_index:
        :rtype: None
        """
        return self.abq_mass_scalings.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(abq_mass_scalings)
        # #     Dim iIndex (2)
        # #     abq_mass_scalings.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQMassScalings(name="{self.name}")'
